@@ -1,5 +1,5 @@
 package Mira::View::Archive;
-$Mira::View::Archive::VERSION = '00.07.47';
+$Mira::View::Archive::VERSION = '00.07.48';
 
 use strict;
 use warnings;
@@ -86,6 +86,8 @@ sub template {
                         catdir( $archive_template_root, 'include' )
                     ],
                     INTERPOLATE => 1,
+                    TRIM      => 1,
+                    EVAL_PERL => 1,
                     ENCODING    => 'utf8',
                     START_TAG   => quotemeta( $config->{$floor}->{t_start_tag} ),
                     END_TAG     => quotemeta( $config->{$floor}->{t_end_tag} ),
