@@ -1,5 +1,5 @@
 package Mira::View::Post;
-$Mira::View::Post::VERSION = '00.07.47';
+$Mira::View::Post::VERSION = '00.07.48';
 
 use strict;
 use warnings;
@@ -91,6 +91,8 @@ sub template {
   	   my $post_index = Template->new({
   	        INCLUDE_PATH => [ $post_template_root, catdir($post_template_root, 'include') ],
             INTERPOLATE  => 1,
+            TRIM      => 1,
+            EVAL_PERL => 1,
             ENCODING => 'utf8',
             START_TAG => quotemeta($config->{$floor}->{t_start_tag}),
             END_TAG   => quotemeta($config->{$floor}->{t_end_tag}),
